@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: nonce
 version: 1.0.2
-id: nonce-1.0.2-c0bfd19efc8c42e1c2c83d3a058f813a
-key: nonce_Aq8Gw0TPkT5H9Hiky2rRh6
+id: nonce-1.0.2-4d1212dfb084a803f723eea311d0a719
+key: nonce_FigQnEvwdJg64LaWzZF5Ot
 license: BSD3
 copyright: (c) 2014 Prowdsponsor
 maintainer: Prowdsponsor <opensource@prowdsponsor.com>
@@ -27,13 +27,13 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/nonce-1.0.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/nonce-1.0.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/nonce-1.0.2
-hs-libraries: HSnonce-1.0.2-Aq8Gw0TPkT5H9Hiky2rRh6
+hs-libraries: HSnonce-1.0.2-FigQnEvwdJg64LaWzZF5Ot
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    cprng-aes-0.6.1-4f88e976d4e99640259c02d6940382c2
-    crypto-random-0.0.9-1a34631cfa2fcb67c67a6201143b0147
+    cprng-aes-0.6.1-31f334ac9b899d0af12f1cbac49d2287
+    crypto-random-0.0.9-bdb6a693941c8915b178724d04100946
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
 haddock-interfaces: /usr/share/doc/haskell-nonce/html/nonce.haddock
